@@ -1,5 +1,5 @@
 package JSON::Karabiner::Rule ;
-$JSON::Karabiner::Rule::VERSION = '0.006';
+$JSON::Karabiner::Rule::VERSION = '0.007';
 use strict;
 use warnings;
 use JSON::Karabiner::Manipulator ;
@@ -17,6 +17,21 @@ sub new {
   return $self;
 }
 
+sub _disable_validity_tests {
+  my $s = shift;
+  my $enable = shift;
+
+  my $op = $enable ? 0 : 1;
+  foreach my $manip (@{$s->{manipulators}}) {
+    $manip->{_disable_validity_tests} = $op;
+  }
+}
+
+sub _enable_validity_tests {
+  my $s = shift;
+  $s->_disable_validity_tests(1);
+}
+
 sub add_manipulator {
   my $s = shift;
 
@@ -49,7 +64,7 @@ Methods are listed below for reference purposes only.
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 AUTHOR
 
